@@ -205,8 +205,8 @@ class WordForm(models.Model):
             sp,bp = t.get_phono_prob()
             sp_sum += sp
             bp_sum += bp
-        sp = float(sp_sum)/float(len(self.transcriptions.all())
-        bp = float(bp_sum)/float(len(self.transcriptions.all())
+        sp = float(sp_sum)/float(len(self.transcriptions.all()))
+        bp = float(bp_sum)/float(len(self.transcriptions.all()))
         return sp,bp
 
 
