@@ -300,6 +300,10 @@ def analyze_block(comp):
 @task()
 def combine_results(allout):
     with open(os.path.join(fetch_media_resource("Results"),"Celex","ConCon.txt"),'w') as f:
+        f.write("\t".join(['orth_one','orth_two','trans_one','trans_two','cat_one',
+                            'cat_two','freq_one','freq_two','lemma_one','lemma_two',
+                            'lemma_freq_one','lemma_freq_two','phon_distance','in_context_entropy']))
+        f.write("\n")
         for l in allout:
             for line in allout:
                 f.write("\t".join(line))
